var _ = require('underscore');
var http = require('http-request');

var sparkpost = function (apiKey) {
    this.apiKey = null;
    this.endpoint = "https://api.sparkpost.com/api/v1/transmissions";
    if (typeof apiKey !== 'undefined' && apiKey !== null) {
        this.apiKey = apiKey
    }
};

sparkpost.prototype.setApiKey = function (apiKey) {
    if (typeof apiKey !== 'undefined' && apiKey !== null) {
        this.apiKey = apiKey
    } else {
        throw new Error("API Key is required!");
    }
};

var isset = function (val) {
    return typeof val !== 'undefined' && val !== null;
};

sparkpost.prototype.send = function (options) {
    if (!isset(this.apiKey)) throw new Error("No API Key set!");
    _opts = {
        tracking: {
            open: true,
            click: true
        }
    };
    _opts = _.defaults(_opts, options);
    var fieldsValid = true;

    if (!isset(_opts.from)) {
        fieldsValid = false;
        throw new Error("'From' object is required!");
    }
    if (!isset(_opts.from.address)) {
        fieldsValid = false;
        throw new Error("'From Address' is required!");
    }
    if (!isset(_opts.from.name)) {
        fieldsValid = false;
        throw new Error("'From Name' is required!");
    }
    if (!isset(_opts.subject)) {
        fieldsValid = false;
        throw new Error("'Subject' is required!");
    }
    if (!isset(_opts.content)) {
        fieldsValid = false;
        throw new Error("'Content' object is required!");
    }
    if (!isset(_opts.content.text)) {
        fieldsValid = false;
        throw new Error("'Text' content is required!");
    }
    if (!isset(_opts.content.html)) {
        fieldsValid = false;
        throw new Error("'HTML' content is required!");
    }

    if (fieldsValid) {
        reqBody = {
            "options": {"open_tracking": _opts.tracking.open, "click_tracking": _opts.tracking.click},
            "recipients": [{"address": {"email": _opts.from.address}}],
            "content": {
                "from": {"name": _opts.from.name, "email": _opts.from.address},
                "subject": _opts.subject,
                "text": _opts.content.text,
                "html": _opts.content.html
            }
        };
        request = http.post({
            url: this.endpoint,
            reqBody: new Buffer(JSON.stringify(reqBody)),
            headers: {
                "Authorization": this.apiKey
            }
        }, function (err, result) {
            console.log(err, result);
        });
    }
};

module.exports = sparkpost;